<!--- Copyright 2021 eprbell --->

<!--- Licensed under the Apache License, Version 2.0 (the "License"); --->
<!--- you may not use this file except in compliance with the License. --->
<!--- You may obtain a copy of the License at --->

<!---     http://www.apache.org/licenses/LICENSE-2.0 --->

<!--- Unless required by applicable law or agreed to in writing, software --->
<!--- distributed under the License is distributed on an "AS IS" BASIS, --->
<!--- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. --->
<!--- See the License for the specific language governing permissions and --->
<!--- limitations under the License. --->

# RP2 Frequently Asked Questions (User)

## Table of Contents

* **[How to Verify That I Entered Data Correctly in the Input Spreadsheet?](#how-to-verify-that-i-entered-data-correctly-in-the-input-spreadsheet)**
* **[What Is the Timestamp Format?](#what-is-the-timestamp-format)**
* **[how to Handle Conversion of a Cryptocurrency to Another?](#how-to-handle-conversion-of-a-cryptocurrency-to-another)**
* **[How to Handle Airdrops?](#how-to-handle-airdrops)**
* **[How to Handle Hard Forks?](#how-to-handle-hard-forks)**
* **[How to Handle Income from Mining?](#how-to-handle-income-from-mining)**
* **[How to Handle Income from Staking?](#how-to-handle-income-from-staking)**
* **[How to Handle Futures and Options?](#how-to-handle-futures-and-options)**
* **[How to Handle NFTs?](#how-to-handle-nfts)**

* **[How to Report a RP2 Bug without Sharing Personal Information?](#how-to-report-a-rp2-bug-without-sharing-personal-information)**

* **[Can I Avoid Writing a Config File From Scratch?](#can-i-avoid-writing-a-config-file-from-scratch)**

* **[If I Transfer Cryptocurrency Between Two Accounts I Own, Is the Fee Taxable?](#if-i-transfer-cryptocurrency-between-two-accounts-i-own-is-the-fee-taxable)**
* **[What if I Transfer Cryptocurrency from My Account to My Spouse's Account and We File Taxes Together?](#what-if-i-transfer-cryptocurrency-from-my-account-to-my-spouses-account-and-we-file-taxes-together)**
* **[What Events Are Taxable?](#what-events-are-taxable)**

* **[Who is the Author of RP2?](#who-is-the-author-of-rp2)**
* **[What Does RP2 Mean?](#what-does-rp2-mean)**

## How to Verify That I Entered Data Correctly in the Input Spreadsheet?
TBD

## What Is the Timestamp Format?
TBD

## How to Handle Conversion of a Cryptocurrency to Another?
TBD

## How to Handle Airdrops?
TBD

## How to Handle Hard Forks?
TBD

## How to Handle Income from Mining?
TBD

## How to Handle Income from Staking?
TBD

## How to Handle Futures and Options?
TBD

## How to Handle NFTs?
TBD

## How to Report a RP2 Bug without Sharing Personal Information?
TBD

## Can I Avoid Writing a Config File From Scratch?
TBD

## If I Transfer Cryptocurrency Between Two Accounts I Own, Is the Fee Taxable?
TBD

## What if I Transfer Cryptocurrency from My Account to My Spouse's Account and We File Taxes Together?
TBD

## What Events Are Taxable?
TBD

## Who is the Author of RP2?
The author of RP2 is a Silicon Valley veteran, a software engineer who left the corporate world to become an independent developer and investor. More on eprbell's story [here](https://eprbell.github.io/eprbell//eprbell/status/2021/07/29/the-beginning-of-the-journey.html).

## What Does RP2 Mean?
It's a humorous reference to Warren Buffett’s claim that Bitcoin is [“rat poison squared”](https://www.cnbc.com/2018/05/05/warren-buffett-says-bitcoin-is-probably-rat-poison-squared.html). Other smart people occasionally made [famously](https://www.snopes.com/fact-check/paul-krugman-internets-effect-economy/) [wrong](https://libquotes.com/thomas-edison/quote/lbx5e7q) [remarks](https://en.wikipedia.org/wiki/Robert_Metcalfe#Incorrect_predictions) about technology: I have a feeling Buffett’s quote might end up among those.
